
/* -------------------------------------------------------------------------- */

/*

ptcl.h

USNO/NRL Optical Interferometer
United States Naval Observatory
3450 Massachusetts Avenue, NW
Washington, DC  20392-5420

Subsystem:
----------
ptcl

Description:
------------
This file contains various definitions for the ptcl package.

Functions:
----------
None.

Modification history:
---------------------
1995 Mar 08 - Nicholas Elias, USNO/AD5
	      File created.

*/

/* -------------------------------------------------------------------------- */

/* Define the PGPLOT/FORTRAN typedefs */

#if F2C
#include "f2c.h"
#endif

#define integer long int
#define real float


/* Declare the ptcl function prototypes */

#include "tcl.h" /* tcl */

int Tcl_AppInit( Tcl_Interp *pmtInterp );

#if COMPILE == 0
void pgarro( real *prXTail, real *prYTail, real *prXHead, real *prYHead );
void pgask( integer *pliFlag );
integer pgband( integer *pliMode, integer *pliPosn, real *prXRef, real *prYRef,
    real *prX, real *prY, char *psChar, integer liCharLen );
void pgbbuf( void );
integer pgbeg( integer *pliUnit, char *psDev, integer *pliNumPlotX,
    integer *pliNumPlotY, integer liDevLen );
void pgbin( integer *pliNumBin, real *prBin, real *prData, integer *pliCenter );
void pgbox( char *psXOpt, real *prXTick, integer *pliNXSub, char *psYOpt,
    real *prYTick, integer *pliNYSub, integer liXOptLen, integer liYOptLen );
void pgcirc( real *prXCent, real *prYCent, real *prRadius );
integer pgcurs( real *prX, real *prY, char *psCH, integer liCHLen );
void pgdraw( real *prX, real *prY );
void pgebuf( void );
void pgend( void );
void pgenv( real *prXAxisLow, real *prXAxisHigh, real *prYAxisLow,
    real *prYAxisHigh, integer *pliScale, integer *pliBox );
void pgeras( void );
void pgerrb( integer *pliDir, integer *pliNumData, real *prErr, real *prX,
    real *prY, real *prSerif );
void pgerrx( integer *pliNumData, real *prXLow, real *prXHigh, real *prY,
    real *prSerif );
void pgerry( integer *pliNumData, real *prX, real *prYLow, real *prYHigh,
    real *prSerif );
void pgetxt( void );
void pghist( integer *pliNumData, real *prData, real *prMin, real *prMax,
    integer *pliNumBin, integer *pliFlag );
void pgiden( void );
void pglab( char *psXLabel, char *psYLabel, char *psTitle,
    integer liXLabelLen, integer liYLabelLen, integer liTitleLen );
void pglcur( integer *pliMaxPt, integer *pliNPt, real *prX, real *prY );
void pgldev( void );
void pglen( integer *pliUnit, char *psString, real *prXL, real *prYL,
    integer liStringLen );
void pgline( integer *pliNumData, real *prX, real *prY );
void pgmove( real *prX, real *prY );
void pgmtxt( char *psSide, real *prDisp, real *prLeftCoord, real *prJust,
    char *psText, integer liSideLen, integer liTextLen );
void pgncur( integer *pliMaxPt, integer *pliNPt, real *prX, real *prY,
    integer *pliSymbol );
void pgnumb( integer *pliMM, integer *pliPP, integer *pliForm, char *psString,
    integer *pliNC, integer liStringLen );
void pgolin( integer *pliMaxPt, integer *pliNPt, real *prX, real *prY,
    integer *pliSymbol );
void pgpage( void );
void pgpanl( integer *pliNXSub, integer *pliNYSub );
void pgpap( real *prWidth, real *prAspect );
void pgpnts( integer *pliNumData, real *prX, real *prY, integer *pliSymbol,
    integer *pliNumSymbol );
void pgpoly( integer *pliNumData, real *prX, real *prY );
void pgpt( integer *pliNumData, real *prX, real *prY, integer *pliSymbol );
void pgptxt( real *prX, real *prY, real *prAngle, real *prJust, char *psText,
    integer liTextLen );
void pgqah( integer *pliFS, real *prAngle, real *prVent );
void pgqcf( integer *pliFont );
void pgqch( real *prSize );
void pgqci( integer *pliCI );
void pgqcir( integer *pliCILow, integer *pliCIHigh );
void pgqcol( integer *pliCILow, integer *pliCIHigh );
void pgqcr( integer *pliCI, real *prCR, real *prCG, real *prCB );
void pgqcs( integer *pliUnits, real *prXCh, real *prYCh );
void pgqfs( integer *pliFS );
void pgqinf( char *psType, char *psResult, integer *pliLen, integer liTypeLen,
    integer liResultLen );
void pgqitf( integer *pliITF );
void pgqls( integer *pliLS );
void pgqlw( integer *pliLW );
void pgqpos( real *prX, real *prY );
void pgqtbg( integer *pliTBG );
void pgqtxt( real *prX, real *prY, real *prAngle, real *prJust, char *psText,
    real *prXBox, real *prYBox, integer liTextLen );
void pgqvp( integer *pliUnit, real *prX1, real *prX2, real *prY1, real *prY2 );
void pgqvsz( integer *pliUnit, real *prX1, real *prX2, real *prY1, real *prY2 );
void pgqwin( real *prX1, real *prX2, real *prY1, real *prY2 );
void pgrect( real *prX1, real *prX2, real *prY1, real *prY2 );
real pgrnd( real *prX, integer *pliNSub );
void pgrnge( real *prLow, real *prHigh, real *prLowBest, real *prHighBest );
void pgsah( integer *pliFS, real *prAngle, real *prVent );
void pgsave( void );
void pgscf( integer *pliFontIndex );
void pgsch( real *prHeight );
void pgsci( integer *pliColorIndex );
void pgscir( integer *pliColorIndex1, integer *pliColorIndex2 );
void pgscr( integer *pliColorIndex, real *prCR, real *prCG, real *prCB );
void pgscrn( integer *pliColorIndex, char *psName, integer *pliError,
    integer liNameLen );
void pgsfs( integer *pliFS );
void pgshls( integer *pliColorIndex, real *prCH, real *prCL, real *prCS );
void pgsitf( integer *pliITFIndex );
void pgsls( integer *pliLineIndex );
void pgslw( integer *pliWidth );
void pgstbg( integer *pliTBGIndex );
void pgsubp( integer *pliNXSub, integer *pliNYSub );
void pgsvp( real *prX1, real *prX2, real *prY1, real *prY2 );
void pgswin( real *prX1, real *prX2, real *prY1, real *prY2 );
void pgtbox( char *psXOpt, real *prXTick, integer *pliNXSub, char *psYOpt,
    real *prYTick, integer *pliNYSub, integer liXOptLen, integer liYOptLen );
void pgtext( real *prX, real *prY, char *psText, integer liTextLen );
void pgunsa( void );
void pgupdt( void );
void pgvsiz( real *prXLeft, real *prXRight, real *prYLeft, real *prYRight );
void pgvstd( void );
void pgwnad( real *prXAxisLow, real *prXAxisHigh, real *prYAxisLow,
    real *prYAxisHigh );
#elif COMPILE == 1
void pgarro_( real *prXTail, real *prYTail, real *prXHead, real *prYHead );
void pgask_( integer *pliFlag );
integer pgband_( integer *pliMode, integer *pliPosn, real *prXRef, real *prYRef,
    real *prX, real *prY, char *psChar, integer liCharLen );
void pgbbuf_( void );
integer pgbeg_( integer *pliUnit, char *psDev, integer *pliNumPlotX,
    integer *pliNumPlotY, integer liDevLen );
void pgbin_( integer *pliNumBin, real *prBin, real *prData,
    integer *pliCenter );
void pgbox_( char *psXOpt, real *prXTick, integer *pliNXSub, char *psYOpt,
    real *prYTick, integer *pliNYSub, integer liXOptLen, integer liYOptLen );
void pgcirc_( real *prXCent, real *prYCent, real *prRadius );
integer pgcurs_( real *prX, real *prY, char *psCH, integer liCHLen );
void pgdraw_( real *prX, real *prY );
void pgebuf_( void );
void pgend_( void );
void pgenv_( real *prXAxisLow, real *prXAxisHigh, real *prYAxisLow,
    real *prYAxisHigh, integer *pliScale, integer *pliBox );
void pgeras_( void );
void pgerrb_( integer *pliDir, integer *pliNumData, real *prErr, real *prX,
    real *prY, real *prSerif );
void pgerrx_( integer *pliNumData, real *prXLow, real *prXHigh, real *prY,
    real *prSerif );
void pgerry_( integer *pliNumData, real *prX, real *prYLow, real *prYHigh,
    real *prSerif );
void pgetxt_( void );
void pghist_( integer *pliNumData, real *prData, real *prMin, real *prMax,
    integer *pliNumBin, integer *pliFlag );
void pgiden_( void );
void pglab_( char *psXLabel, char *psYLabel, char *psTitle,
    integer liXLabelLen, integer liYLabelLen, integer liTitleLen );
void pglcur_( integer *pliMaxPt, integer *pliNPt, real *prX, real *prY );
void pgldev_( void );
void pglen_( integer *pliUnit, char *psString, real *prXL, real *prYL,
    integer liStringLen );
void pgline_( integer *pliNumData, real *prX, real *prY );
void pgmove_( real *prX, real *prY );
void pgmtxt_( char *psSide, real *prDisp, real *prLeftCoord, real *prJust,
    char *psText, integer liSideLen, integer liTextLen );
void pgncur_( integer *pliMaxPt, integer *pliNPt, real *prX, real *prY,
    integer *pliSymbol );
void pgnumb_( integer *pliMM, integer *pliPP, integer *pliForm, char *psString,
    integer *pliNC, integer liStringLen );
void pgolin_( integer *pliMaxPt, integer *pliNPt, real *prX, real *prY,
    integer *pliSymbol );
void pgpage_( void );
void pgpanl_( integer *pliNXSub, integer *pliNYSub );
void pgpap_( real *prWidth, real *prAspect );
void pgpnts_( integer *pliNumData, real *prX, real *prY, integer *pliSymbol,
    integer *pliNumSymbol );
void pgpoly_( integer *pliNumData, real *prX, real *prY );
void pgpt_( integer *pliNumData, real *prX, real *prY, integer *pliSymbol );
void pgptxt_( real *prX, real *prY, real *prAngle, real *prJust, char *psText,
    integer liTextLen );
void pgqah_( integer *pliFS, real *prAngle, real *prVent );
void pgqcf_( integer *pliFont );
void pgqch_( real *prSize );
void pgqci_( integer *pliCI );
void pgqcir_( integer *pliCILow, integer *pliCIHigh );
void pgqcol_( integer *pliCILow, integer *pliCIHigh );
void pgqcr_( integer *pliCI, real *prCR, real *prCG, real *prCB );
void pgqcs_( integer *pliUnits, real *prXCh, real *prYCh );
void pgqfs_( integer *pliFS );
void pgqinf_( char *psType, char *psResult, integer *pliLen, integer liTypeLen,
    integer liResultLen );
void pgqitf_( integer *pliITF );
void pgqls_( integer *pliLS );
void pgqlw_( integer *pliLW );
void pgqpos_( real *prX, real *prY );
void pgqtbg_( integer *pliTBG );
void pgqtxt_( real *prX, real *prY, real *prAngle, real *prJust, char *psText,
    real *prXBox, real *prYBox, integer liTextLen );
void pgqvp_( integer *pliUnit, real *prX1, real *prX2, real *prY1, real *prY2 );
void pgqvsz_( integer *pliUnit, real *prX1, real *prX2, real *prY1,
    real *prY2 );
void pgqwin_( real *prX1, real *prX2, real *prY1, real *prY2 );
void pgrect_( real *prX1, real *prX2, real *prY1, real *prY2 );
real pgrnd_( real *prX, integer *pliNSub );
void pgrnge_( real *prLow, real *prHigh, real *prLowBest, real *prHighBest );
void pgsah_( integer *pliFS, real *prAngle, real *prVent );
void pgsave_( void );
void pgscf_( integer *pliFontIndex );
void pgsch_( real *prHeight );
void pgsci_( integer *pliColorIndex );
void pgscir_( integer *pliColorIndex1, integer *pliColorIndex2 );
void pgscr_( integer *pliColorIndex, real *prCR, real *prCG, real *prCB );
void pgscrn_( integer *pliColorIndex, char *psName, integer *pliError,
    integer liNameLen );
void pgsfs_( integer *pliFS );
void pgshls_( integer *pliColorIndex, real *prCH, real *prCL, real *prCS );
void pgsitf_( integer *pliITFIndex );
void pgsls_( integer *pliLineIndex );
void pgslw_( integer *pliWidth );
void pgstbg_( integer *pliTBGIndex );
void pgsubp_( integer *pliNXSub, integer *pliNYSub );
void pgsvp_( real *prX1, real *prX2, real *prY1, real *prY2 );
void pgswin_( real *prX1, real *prX2, real *prY1, real *prY2 );
void pgtbox_( char *psXOpt, real *prXTick, integer *pliNXSub, char *psYOpt,
    real *prYTick, integer *pliNYSub, integer liXOptLen, integer liYOptLen );
void pgtext_( real *prX, real *prY, char *psText, integer liTextLen );
void pgunsa_( void );
void pgupdt_( void );
void pgvsiz_( real *prXLeft, real *prXRight, real *prYLeft, real *prYRight );
void pgvstd_( void );
void pgwnad_( real *prXAxisLow, real *prXAxisHigh, real *prYAxisLow,
    real *prYAxisHigh );
#include "f2c.h"
#elif COMPILE == 2
#include "cpgplot.h" /* PGPLOT C wrapper function prototypes */
#else
#include "cpgplot.h" /* PGPLOT C wrapper function prototypes */
#endif

